
# Coding and Using a Module

## Module "rec"

Assume we have a basic Node.js project directory "rec" that
is a standard Node.js project directory.

To make this directory a proper module we set the
"name" and "main" properties in "package.json" like
in this example:

```
  "name": "rec",
  "main": "factory.js"
```  

## Using Module (Local Dependency)

Assume we are now working in another project, and we want to use
the module locally (i.e., say the module is not published).

We are working in the "rec-user" directory (a sibling of the "rec" directory above).

To use the module locally, we add this dependency to "package.json":

```
  "dependencies": {
    "rec": "file:../rec"
  }
```

We could also use an absolute path, but lose portability:
```
    "rec": "file:/Work/cincom/vse/Work/_newWork/XDOC/Version3/_Code/Node/900labs/coding-modules/
```

NOTE WELL -- the path shown here may need to be adjusted as the example may have
been unzipped to a different path.

These are all the prefixes we can use for the local path:

```
	../foo
	~/foo
	./foo
	/foo
```

## Dependency for Published

If the module is published, then we add the dependency to "rec-user/package.json" as:

```
  "dependencies": {
    "rec": "^1.0.0"
  }
```

## Installing Dependency

We use "npm" in the normal way to install project dependencies (which
will include the new "rec" module).

```
	>npm install
```

## Using in Code

Now we can code normally.

```
const
	{Factory} = require('rec');

//...
	const model = Factory.newTwoRec(10, 2, 8, 7);
	console.log(model.toString());
```